ModelInfo class

Information about a model with @SynquillDataRepository annotation

Constructors

ModelInfo({required String className, required String tableName, required String endpoint, required String importPath, required List<FieldInfo> fields, List<AdapterInfo>? adapters, List<RelationInfo> relations = const [], bool localOnly = false, String idGeneration = 'client'})
Creates a new instance of ModelInfo.
const

Properties

adapters List<AdapterInfo>?
The adapters for this model (if any).
final
className String
The name of the model class.
final
endpoint String
The API endpoint for this model.
final
fields List<FieldInfo>
The fields of the model.
final
hashCode int
The hash code for this object.
no setterinherited
idGeneration String
ID generation strategy for this model. Determines whether IDs are generated on client or server side.
final
importPath String
The import path for the model file.
final
localOnly bool
Whether this repository should work in local-only mode. When true, the repository will not attempt to sync with remote API.
final
relations List<RelationInfo>
Class-level relationships (OneToMany and ManyToOne) defined in @SynquillRepository.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
The name of the database table for this model.
final
usesServerGeneratedId bool
Whether this model uses server-generated IDs.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited